@@ -175,26 +175,30 @@ namespace Lum {
 
   void ButtonRow::Layout()
   {
-    std::list<Object*>::const_iterator   opt;
-    std::list<Object*>::reverse_iterator cmd; // We should use const_reverse_iterator, but there is a bug in gcc <=4.0
-    int                                  pos;
+    int pos;
+
+    // If we have small displays we should make the button row fill its
+    // size completely by resizing the buttons beyond their minimal sizes
+    if (OS::display->GetSize()<=OS::Display::sizeSmall) {
+      // TODO
+    }
 
     pos=x;
-    opt=optional.begin();
-    while (opt!=optional.end()) {
+    for (std::list<Object*>::const_iterator opt=optional.begin();
+         opt!=optional.end();
+         ++opt) {
       (*opt)->Move(pos,y+(height-(*opt)->GetOHeight())/2);
 
       pos+=(*opt)->GetOWidth()+OS::display->GetSpaceHorizontal(OS::Display::spaceInterObject);
-      ++opt;
     }
 
     pos=x+width-buttonWidth;
-    cmd=command.rbegin();
-    while (cmd!=command.rend()) {
+    // We should use const_reverse_iterator, but there is a bug in gcc <=4.0
+    for (std::list<Object*>::reverse_iterator cmd=command.rbegin();
+         cmd!=command.rend();
+         ++cmd) {
       (*cmd)->Move(pos,y + (height-(*cmd)->GetOHeight()) / 2);
       pos-=(*cmd)->GetOWidth()+OS::display->GetSpaceHorizontal(OS::Display::spaceInterObject);
-
-      ++cmd;
     }
 
     Group::Layout();
