@@ -361,6 +361,10 @@ namespace Lum {
 
     void File::SetPath(const std::wstring& path)
     {
+      if (path.empty()) {
+        return;
+      }
+
       if (options->existingOnly &&
           !Base::Path::Exists(path)) {
         return;
@@ -539,33 +543,33 @@ namespace Lum {
     */
     void File::OnOk()
     {
-      Base::DirScanner::Entry entry;
-
-      if (!GetSelection(entry)) {
-        return;
-      }
-
       Base::Path newPath(full->Get());
 
       if (options->mode==Options::modeDirectory) {
-        if (entry.isDir) {
-          if (newPath.Exists() && newPath.IsDir()) {
-            result=true;
-            Exit();
-          }
+        if (newPath.Exists() && newPath.IsDir()) {
+          result=true;
+          Exit();
         }
       }
-      else if (!options->existingOnly) {
-        result=true;
-        Exit();
-      }
-      else if (entry.isDir) {
-        newPath.AppendDir(entry.name);
-        path->Set(newPath);
-      }
-      else if (options->existingOnly && newPath.Exists() && !newPath.IsDir()) {
-        result=true;
-        Exit();
+      else {
+        if (!options->existingOnly) {
+          result=true;
+          Exit();
+        }
+        else if (options->existingOnly &&
+                 newPath.Exists() && !newPath.IsDir()) {
+          result=true;
+          Exit();
+        }
+        else {
+          Base::DirScanner::Entry entry;
+
+          if (GetSelection(entry)) {
+            if (entry.isDir) {
+              GotoChildDirectory(entry.name);
+            }
+          }
+        }
       }
     }
 
