@@ -48,7 +48,8 @@ namespace Lum {
         class MenuPopup : public Popup
         {
         private:
-          std::set<Model::Action*> actions;
+          std::set<Model::Action*>  actions;
+          std::set<Model::Boolean*> booleans;
 
         private:
           void AddToPopupArray(Array* array,
@@ -83,7 +84,14 @@ namespace Lum {
                 Def::MenuBoolean *boolean=dynamic_cast<Def::MenuBoolean*>(*iter);
 
                 if (excludes.find(boolean->GetBoolean().GetBoolean())==excludes.end()) {
-                  // TODO
+                  Def::Boolean b=boolean->GetBoolean();
+
+                  booleans.insert(b.GetBoolean());
+                  ObservePrior(b.GetBoolean());
+
+                  Lum::Object *object=OS::display->GetBehaviour()->GetBooleanControl(b,true,false);
+
+                  array->Add(object);
                 }
               }
               else if (dynamic_cast<Def::MenuOneOfN*>(*iter)!=NULL) {
@@ -138,6 +146,18 @@ namespace Lum {
                 }
               }
             }
+            else if (dynamic_cast<Model::Boolean*>(model)!=NULL) {
+              Model::BooleanRef boolean=dynamic_cast<Lum::Model::Boolean*>(model);
+
+              if (booleans.find(boolean)!=booleans.end()) {
+                if (boolean->IsEnabled() &&
+                    IsOpen() &&
+                    IsShown()) {
+                  Hide();
+                  return;
+                }
+              }
+            }
 
             Popup::Resync(model,msg);
           }
