@@ -75,6 +75,11 @@ namespace Lum {
       height=label->GetOHeight();
     }
 
+    if (OS::display->GetTheme()->RequestFingerFriendlyControls()) {
+      SetMinWidth(OS::display->GetTheme()->GetFingerFriendlyMinWidth());
+      SetMinHeight(OS::display->GetTheme()->GetFingerFriendlyMinHeight());
+    }
+
     State::CalcSize();
   }
 
